#! /usr/bin/env python
'''
Module Name:    Configs.py

Description:    This is the container class for all the configuration parser classes

Copyright:      Toshiba Confidential

                OCO Source Materials

                Copyright (C) 2012,2013 Toshiba Global Commerce Solutions, Inc.

                The source code for this program is not published
                or otherwise divested of its trade secrets,
                irrespective of what has been deposited with the
                U. S. Copyright Office.

Initial Author: Francisco Liwa

Function:

Notes:

Dependencies:    None

Restrictions:    None

Last Modified: 30 September 2013

'''
import os

#importing helper modules 
from monitorupgrade import MUSConfigParser
from monitorupgrade import TLog as TLOG



#Globals
FILE_FOUND = 1
FILE_NOT_FOUND = 0
EXIT_SUCCESS = 0
EXIT_FAILURE = 1 
UNKNOWN = -1
NO_MONITORS_ATTACHED = 0

#Error Codes
ERROR_CODE_DEVICE_NOT_EXIST = 4
ERROR_CODE_OPERATION_FAILED = 11
ERROR_CODE_INVALID_PARAM = 21

#Error Strings
ERROR_STR_DEVICE_NOT_EXIST = 'Device not exist'
ERROR_STR_OPERATION_FAILED = 'Operation failed'
ERROR_STR_INVALID_PARAM = 'Invalid Parameter'
ERROR_STR_Runtime = 'Runtime error'

    
ELO_CONF = '/opt/toshiba/mus/UpdateTasks/TouchConfig/EloTouch/toshiba-mus2.0_up_2xx5xx_touch-config_elo/eloConfigOpt.ini'
MUS_LOG_FILE_DIR = '/var/log/toshiba/mus/latest'
MUS_CONF = '/opt/toshiba/mus/mus.conf'



#sampo stuffs here
SAMPO_UTIL = '/opt/toshiba/mus/op_utils/sampo/4820MonUtil'
RECOVERY_FILE_SUSE = '/etc/init.d/after.local'
RECOVERY_STR = '4820MonUtil'

#ELO Stuffs here    
ELO_DOWNLOAD = '/opt/toshiba/mus/op_utils/elo/EloDownload.sh'
ELO_CONFIG = '/opt/toshiba/mus/op_utils/elo/EloConfig.sh'
LSTMON = '/usr/bin/lstmon'
RSTELO = '/usr/bin/rstelo'
CHKELOPATCH = '/usr/bin/chk_elo_patch'
CHKFOUSB = '/usr/bin/chk_fousb'
IBM_VID = '04b3'
ELO_VID = '04e7'
UP_RPMS_DIR = '/opt/toshiba/mus/RpmUpdates'
                

#==========================================================================================================
'''
EloUtilityConfig - Class to handle the contents of eloConfOpt.ini
'''
#==========================================================================================================
class EloUtilityConfig(object):
    conf_path=''
    def __init__(self,path):
        '''
        Constructor
        '''
        #print 'EloUtilityConfig Constructed'
        self.conf_path = path
        
        TLOG.logger.info('EloUtilityConfig Constructed')
        TLOG.logger.info('EloUtilityConfig -Calling MUSConfigParser() ')
        self.config = MUSConfigParser.MUSConfigParser()
        
        TLOG.logger.info('EloUtilityConfig -Reading configuration file '+ str(self.conf_path) ) 
        self.config.readConfig(self.conf_path)
        
        self.options = self.config.getOptionList() 
        #print self.options
        
    
    def getEloOptionValue(self,option):
        
        config = self.config                         
        TLOG.logger.info('EloUtilityConfig::getEloOptionValue() -' + option + '=' + config.ConfigSectionMap("UserDefinedData")[option] )
        
        return config.ConfigSectionMap("UserDefinedData")[option]
               
    def printConfig(self):
        
        self.config.dump()

#==========================================================================================================
'''
UpdateTaskConfig - Class to handle the contents of updatetask.conf
'''
#==========================================================================================================
class UpdateTaskConfig(object):
    def __init__(self,conf_path):
        '''
        Constructor
        '''
        #print 'UpdateTaskConfig Constructed'
        
        TSK_CONF = (os.path.join(conf_path,'tsk.manifest'))
        
        TLOG.logger.info('UpdateTaskConfig Constructed')
        TLOG.logger.info('UpdateTaskConfig -Calling MUSConfigParser() ')
        self.config = MUSConfigParser.MUSConfigParser()
        
        TLOG.logger.info('UpdateTaskConfig -Reading configuration file '+ TSK_CONF)
        self.config.readConfig(TSK_CONF)
        
         
    def getTaskType(self):
        
        config = self.config      
        tsktype  =  config.ConfigSectionMap('asection')['type']                   
        TLOG.logger.info('UpdateTaskConfig::getTaskType() - task_type = ' + tsktype  )
        
        return tsktype
    
    def getFirmwareName(self):
        
        config = self.config      
        fw_manu_name  =  config.ConfigSectionMap('asection')['fw_manu_name']                   
        TLOG.logger.info('UpdateTaskConfig::getFirmwareName() - fw_manu_name = ' + fw_manu_name  )
        
        return fw_manu_name

    def getFirmwareLevel(self):
        
        config = self.config      
        fw  =  config.ConfigSectionMap('asection')['fw_level']                   
        TLOG.logger.info('UpdateTaskConfig::getFirmwareLevel() - FW_LEVEL= ' + fw  )
        
        fw_level = fw.strip('\'')
        
        return fw_level
    
    def getXcfgLevel(self):
        
        config = self.config      
        xcfg  =  config.ConfigSectionMap('asection')['xcfg_level']                   
        TLOG.logger.info('UpdateTaskConfig::getXcfgLevel() - XCFG_LEVEL= ' + xcfg  )
        
        xcfg_level = xcfg.strip('\'')
        
        return xcfg_level
    
    def getMCUFirmwareLevel(self):
        
        config = self.config      
        fw  =  config.ConfigSectionMap('asection')['mcu_fw_level']                   
        TLOG.logger.info('UpdateTaskConfig::getMCUFirmwareLevel() - MCU_FW_LEVEL= ' + fw  )
        
        mcu_fw_level = int (fw.strip('\n'))
        
        return mcu_fw_level
        
    
    def getScalarFirmwareLevel(self):
        
        config = self.config      
        fw  =  config.ConfigSectionMap('asection')['scalar_fw_level']                   
        TLOG.logger.info('UpdateTaskConfig::getScalarFirmwareLevel() - SCALAR_FW_LEVEL= ' + fw  )
        
        scalar_fw_level = int (fw.strip('\n'))
        
        return scalar_fw_level
    
    def getCapsenseFirmwareLevel(self):
        
        config = self.config      
        fw =  config.ConfigSectionMap('asection')['capsense_fw_level']                   
        TLOG.logger.info('UpdateTaskConfig::getCapsenseFirmwareLevel() - CAPSENSE_FW_LEVEL= ' + fw  )
        
        capsense_fw_level = int(fw.strip('\n')) 
        
        return capsense_fw_level
    
    def getAtmelFirmwareName(self):
        
        config = self.config      
        fw_name  =  config.ConfigSectionMap('asection')['atmel_fw_name']                   
        TLOG.logger.info('UpdateTaskConfig::getAtmelFirmwareName() - ATMEL_FW_NAME= ' + fw_name  )
        
        fw_name = fw_name.strip('\'')
        
        return fw_name
    
    def getAtmelCfgName(self):
        
        config = self.config      
        cfg_name =  config.ConfigSectionMap('asection')['atmel_cfg_name']                   
        TLOG.logger.info('UpdateTaskConfig::getAtmelCfgName() - ATMEL_CFG_NAME = ' + cfg_name  )
        
        return cfg_name
    
    def getFirmwarePath(self):
        
        config = self.config      
        fw_path  =  config.ConfigSectionMap('asection')['fw_path']                   
        TLOG.logger.info('UpdateTaskConfig::getFirmwarePath() - fw_path = ' + fw_path )
        
        return fw_path
               
    def printConfig(self):
        
        self.config.dump()
        
        
#==========================================================================================================
'''
MusConfig - Class to handle the contents of mus_conf.ini
'''
#==========================================================================================================

class MusConfig(object):
    def __init__(self):
        '''
        Constructor
        '''
        #print 'UpdateTaskConfig Constructed'
        
        TLOG.logger.info('MusConfig Constructed')
        TLOG.logger.info('MusConfig -Calling MUSConfigParser() ')
        self.config = MUSConfigParser.MUSConfigParser()
        
        TLOG.logger.info('MusConfig -Reading configuration file '+ MUS_CONF)
        self.config.readConfig(MUS_CONF)
        
         
    def getRetryCount(self):
        
        config = self.config      
        retry  =  config.ConfigSectionMap("asection")['recovery_attempt']                   
               
        return retry
    
    def getEloTouchFlashAppPath(self):
         
        config = self.config      
        path  =  config.ConfigSectionMap("EloTouchFlash")['path']                   
        TLOG.logger.info('MusConfig::getEloTouchFlashAppPath() - path = ' + path  )
        
        return path
    
    def getSampoVideoFlashAppPath(self):
        
        config = self.config      
        path  =  config.ConfigSectionMap("SampoVideoFlash")['path']                   
        TLOG.logger.info('MusConfig::getSampoVideoFlashAppPath() - path = ' + path  )
        
        return path
               
    def printConfig(self):
        
        self.config.dump()
